==> struts-2.5.26-all.zip: struts-2.5.26/src/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.views.jsp.ui;

import ognl.Ognl;
import ognl.OgnlException;

import com.opensymphony.xwork2.inject.Inject;
import com.opensymphony.xwork2.ognl.OgnlUtil;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * FIXME: remove?
 */
public class OgnlTool {

    private static final Logger LOG = LogManager.getLogger(OgnlTool.class);

    private OgnlUtil ognlUtil;
    
    public OgnlTool() {
    }
    
    @Inject
    public void setOgnlUtil(OgnlUtil ognlUtil) {
        this.ognlUtil = ognlUtil;
    }
    
    public Object findValue(String expr, Object context) {
        try {
            return Ognl.getValue(ognlUtil.compile(expr), context);
        } catch (OgnlException e) {
            if (e.getReason() instanceof SecurityException) {
                LOG.warn("Could not evaluate this expression due to security constraints: [{}]", expr, e);
            }
            return null;
        }
    }
}

==> struts-6.1.1-all.zip: struts-6.1.1/src/core/src/main/java/org/apache/struts2/views/jsp/ui/OgnlTool.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.views.jsp.ui;

import com.opensymphony.xwork2.ActionContext;
import ognl.OgnlException;

import com.opensymphony.xwork2.inject.Inject;
import com.opensymphony.xwork2.ognl.OgnlUtil;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

/**
 * FIXME: remove?
 */
public class OgnlTool {

    private static final Logger LOG = LogManager.getLogger(OgnlTool.class);

    private OgnlUtil ognlUtil;

    public OgnlTool() {
    }

    @Inject
    public void setOgnlUtil(OgnlUtil ognlUtil) {
        this.ognlUtil = ognlUtil;
    }

    public Object findValue(String expr, Object context) {
        try {
            return ognlUtil.getValue(expr, ActionContext.getContext().getContextMap(), context);
        } catch (OgnlException e) {
            if (e.getReason() instanceof SecurityException) {
                LOG.error("Could not evaluate this expression due to security constraints: [{}]", expr, e);
            }
            return null;
        }
    }
}
